/*------------------------------------------------------------------------------
Name:      ClientGet.java
Project:   xmlBlaster.org
Copyright: xmlBlaster.org, see xmlBlaster-LICENSE file
Comment:   Demo code for a client using xmlBlaster
Version:   $Id: ClientQuery.java,v 1.21 2002/07/24 12:12:33 ruff Exp $
------------------------------------------------------------------------------*/
package javaclients;

import org.jutils.log.LogChannel;
import org.jutils.init.Args;

import org.xmlBlaster.util.Global;
import org.xmlBlaster.util.XmlBlasterException;
import org.xmlBlaster.client.protocol.XmlBlasterConnection;
import org.xmlBlaster.client.UpdateKey;
import org.xmlBlaster.engine.helper.MessageUnit;


/**
 * This client allows you to query xmlBlaster synchronous with method get().
 * <p>
 * It doesn't implement a Callback server, since it only access xmlBlaster
 * using the synchronous get() method.
 * <p>
 * Invoke example:<br />
 * <pre>
 *    java javaclients.ClientQuery -queryXpath "//key"
 * </pre>
 */
public class ClientQuery
{
   private static String ME = "ClientQuery";
   private final LogChannel log;
   private String queryString;
   private String queryType = "XPATH";

   public ClientQuery(String args[])
   {
      // Initialize command line argument handling (this is optional)
      Global glob = new Global();
      log = glob.getLog(null);
      if (glob.init(args) != 0) usage("Aborted");

      try {
         String loginName = Args.getArg(args, "-loginName", ME); // check if parameter -loginName <userName> is given at startup of client
         String passwd = Args.getArg(args, "-passwd", "secret");

         queryString = Args.getArg(args, "-queryXpath", (String)null);
         if (queryString != null)
            queryType = "XPATH";
         else
            usage("Please enter a query string");

         XmlBlasterConnection con = new XmlBlasterConnection(args);
         con.login(loginName, passwd, null);


         String xmlKey = "<key oid='' queryType='" + queryType + "'>\n" +
                            queryString +
                         "</key>";
         MessageUnit[] msgArr = null;
         try {
            msgArr = con.get(xmlKey, "<qos></qos>");
            log.info(ME, "Got " + msgArr.length + " messages for query '" + queryString + "':");
            for (int ii=0; ii<msgArr.length; ii++) {
               UpdateKey updateKey = new UpdateKey(glob, msgArr[ii].xmlKey);
               log.info("UpdateKey", "\n" + updateKey.toXml());
               log.info("content", "\n" + new String(msgArr[ii].content) + "\n");
            }
         } catch(XmlBlasterException e) {
            log.error(ME, "XmlBlasterException: " + e.reason);
         }

         con.disconnect(null);
      }
      catch (org.jutils.JUtilsException e) {
          log.error(ME, "Error occurred: " + e.toString());
          e.printStackTrace();
      }
      catch (XmlBlasterException e) {
          log.error(ME, "Error occurred: " + e.toString());
          e.printStackTrace();
      }
   }

   private void usage(String text)
   {
      log.plain(ME, "\nAvailable options:");
      log.plain(ME, "   -queryXpath         \"//key\"");
      XmlBlasterConnection.usage();
      log.plain(ME, "Example: java javaclients.ClientQuery -queryXpath //key\n");
      log.plain(ME, text);
      System.exit(1);
   }

   public static void main(String args[]) {
      new ClientQuery(args);
   }
}
